#' Herleitung der Wasserhaushaltslimitierung nach der NEK-Methode Version 2023
#'
#' Mit der NEK werden Standorte hinsichtlich ihrer landwirtschaftlichen Nutzungseignung beurteilt.
#' Dabei werden Boden, Klima und Terrain berücksichtigt.
#' Dieses Beurteilungsschema wurde hier publiziert:
#'
#' Greiner, L.; Petter, G.; Keller, A. (2023): Anleitung zur Beurteilung der
#' landwirtschaftlichen Nutzungseignung. Methode der Nutzungseignungsklassen (NEK-Methode).
#' Aktualisierte Version 2023. Kompetenzzentrum Boden KOBO. BFH-HAFL.
#'
#'
#' Die hier vorliegende Beurteilung basiert
#' auf den Bewertungstabellen der NEK-2023 Stand 24.10.2023
#'
#'
#'
#' @param whug Wasserhaushaltsuntergruppe nach FAL24
#' @param klimalim Klimatische Limitierung hergeleitet aus den Klimaeignungszonen
#' @param bewertungstab Bewertungstabelle mit der Zurordung der Wasserhaushaltuntegruppen zu einer NEK nach der klimatischer Limitierung unterteilt
#' @return Die NEK, welche aus der Limitierung durch den Wasserhaushalt und das Klima ergibt
#' @export


nek_whg<- function(whug, klimalim,bewertungstab){



  # Anwenden der Bewertung-----------------------------
  anz_profile<-length(whug)

  # Schauen in welchen Zeilen die Bedinungen für die NEK-Zuordnung erfüllt sind
  index_whug1 <- array(NaN,dim=c(anz_profile,1))
  startspalte_nek <- 2
  for(i in 1:anz_profile){
    if(!is.nan(whug[i])){

      index_temp_whug     <- which(whug[i]==bewertungstab[,1])


      index_col <- klimalim[i] + startspalte_nek-1
      if (!is.na(klimalim[i]) & klimalim[i]<=4){
        common_index <- index_temp_whug

        if (length(common_index)>0){
          Bewertungen=bewertungstab[common_index, index_col]
          index_whug1[i]=common_index[min(which(Bewertungen==min(Bewertungen)))]
        }
      }
    }
  }



  # NEK zuordnen
  nek_whug     <- array(NaN,dim=c(anz_profile,1))

  for(i in 1:anz_profile){
    if (!is.na(klimalim[i]) & klimalim[i]<=4){
      index_col <- klimalim[i] + startspalte_nek-1
    } else {
      index_col <- NaN
    }
    if (!is.nan(index_col)& !is.nan(index_whug1[i])){
      nek_whug[i] <- bewertungstab[[index_whug1[i], index_col]] }
  }

  return(nek_whug)


}
